@@ -1,6 +1,7 @@
 from .core import validate
-from .validators import required, format_email, length_max, length_min, length, type_, lt, gt, eq, ne, gte, lte, _value
+from .validators import required, format_email, length_max, length_min, length, type_, lt, gt, eq, ne, gte, lte, _value, regex_, true_if_empty, in_
 from .decorators import validate_fn
+from .utils import dummy_gettext, selector_as_string
 
 
 __all__ = ['validate',
@@ -11,11 +12,15 @@ __all__ = ['validate',
            'length_min',
            'length',
            'type_',
+           'regex_',
            '_value',
+           'in_',
            'lt',
            'gt',
            'eq',
            'ne',
            'gte',
            'lte',
-           'true_if_empty']
+           'true_if_empty',
+           'dummy_gettext',
+           'selector_as_string']
